Regulatory Compliance details for CIS Microsoft Azure Foundations Benchmark 1.3.0 - Azure Policy | Microsoft Docs
Author: DCtheGeek
Description: Details of the CIS Microsoft Azure Foundations Benchmark 1.3.0 Regulatory Compliance built-in initiative. Each control is mapped to one or more Azure Policy definitions that assist with assessment.

Skip to main content

- Feedback
- Edit

# Details of the CIS Microsoft Azure Foundations Benchmark 1.3.0 Regulatory Compliance built-in initiative

- 03/05/2021
- 31 minutes to read
- - D

The following article details how the Azure Policy Regulatory Compliance built-in initiative definition maps to compliance domains and controls in CIS Microsoft Azure Foundations Benchmark 1.3.0. For more information about this compliance standard, see CIS Microsoft Azure Foundations Benchmark 1.3.0 . To understand Ownership , see Azure Policy policy definition and Shared responsibility in the cloud .

The following mappings are to the CIS Microsoft Azure Foundations Benchmark 1.3.0 controls. Use the navigation on the right to jump directly to a specific compliance domain . Many of the controls are implemented with an Azure Policy initiative definition. To review the complete initiative definition, open Policy in the Azure portal and select the Definitions page. Then, find and select the CIS Microsoft Azure Foundations Benchmark 1.3.0 Regulatory Compliance built-in initiative definition.

Important

Each control below is associated with one or more Azure Policy definitions. These policies may help you assess compliance with the control; however, there often is not a 1:1 or complete match between a control and one or more policies. As such, Compliant in Azure Policy refers only to the policy definitions themselves; this doesn't ensure you're fully compliant with all requirements of a control. In addition, the compliance standard includes controls that aren't addressed by any Azure Policy definitions at this time. Therefore, compliance in Azure Policy is only a partial view of your overall compliance status. The associations between compliance domains, controls, and Azure Policy definitions for this compliance standard may change over time. To view the change history, see the GitHub Commit History .

## Identity and Access Management

### Ensure that multi-factor authentication is enabled for all privileged users

ID : CIS Azure 1.1 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
MFA should be enabled accounts with write permissions on your subscription | Multi-Factor Authentication (MFA) should be enabled for all subscription accounts with write privileges to prevent a breach of accounts or resources. | AuditIfNotExists, Disabled | 3.0.0
MFA should be enabled on accounts with owner permissions on your subscription | Multi-Factor Authentication (MFA) should be enabled for all subscription accounts with owner permissions to prevent a breach of accounts or resources. | AuditIfNotExists, Disabled | 3.0.0

### Ensure that multi-factor authentication is enabled for all non-privileged users

ID : CIS Azure 1.2 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
MFA should be enabled on accounts with read permissions on your subscription | Multi-Factor Authentication (MFA) should be enabled for all subscription accounts with read privileges to prevent a breach of accounts or resources. | AuditIfNotExists, Disabled | 3.0.0

### Ensure guest users are reviewed on a monthly basis

ID : CIS Azure 1.3 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
External accounts with owner permissions should be removed from your subscription | External accounts with owner permissions should be removed from your subscription in order to prevent unmonitored access. | AuditIfNotExists, Disabled | 3.0.0
External accounts with read permissions should be removed from your subscription | External accounts with read privileges should be removed from your subscription in order to prevent unmonitored access. | AuditIfNotExists, Disabled | 3.0.0
External accounts with write permissions should be removed from your subscription | External accounts with write privileges should be removed from your subscription in order to prevent unmonitored access. | AuditIfNotExists, Disabled | 3.0.0

### Ensure that no custom subscription owner roles are created

ID : CIS Azure 1.21 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Custom subscription owner roles should not exist | This policy ensures that no custom subscription owner roles exist. | Audit, Disabled | 2.0.0

## Security Center

### Ensure that Azure Defender is set to On for Servers

ID : CIS Azure 2.1 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Azure Defender for servers should be enabled | Azure Defender for servers provides real-time threat protection for server workloads and generates hardening recommendations as well as alerts about suspicious activities. | AuditIfNotExists, Disabled | 1.0.3

### Ensure that Azure Defender is set to On for App Service

ID : CIS Azure 2.2 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Azure Defender for App Service should be enabled | Azure Defender for App Service leverages the scale of the cloud, and the visibility that Azure has as a cloud provider, to monitor for common web app attacks. | AuditIfNotExists, Disabled | 1.0.3

### Ensure that Azure Defender is set to On for Azure SQL database servers

ID : CIS Azure 2.3 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Azure Defender for Azure SQL Database servers should be enabled | Azure Defender for SQL provides functionality for surfacing and mitigating potential database vulnerabilities, detecting anomalous activities that could indicate threats to SQL databases, and discovering and classifying sensitive data. | AuditIfNotExists, Disabled | 1.0.2

### Ensure that Azure Defender is set to On for SQL servers on machines

ID : CIS Azure 2.4 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Azure Defender for SQL servers on machines should be enabled | Azure Defender for SQL provides functionality for surfacing and mitigating potential database vulnerabilities, detecting anomalous activities that could indicate threats to SQL databases, and discovering and classifying sensitive data. | AuditIfNotExists, Disabled | 1.0.2

### Ensure that Azure Defender is set to On for Storage

ID : CIS Azure 2.5 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Azure Defender for Storage should be enabled | Azure Defender for Storage provides detections of unusual and potentially harmful attempts to access or exploit storage accounts. | AuditIfNotExists, Disabled | 1.0.3

### Ensure that Azure Defender is set to On for Kubernetes

ID : CIS Azure 2.6 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Azure Defender for Kubernetes should be enabled | Azure Defender for Kubernetes provides real-time threat protection for containerized environments and generates alerts for suspicious activities. | AuditIfNotExists, Disabled | 1.0.3

### Ensure that Azure Defender is set to On for Container Registries

ID : CIS Azure 2.7 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Azure Defender for container registries should be enabled | Azure Defender for container registries provides vulnerability scanning of any images pulled within the last 30 days, pushed to your registry, or imported, and exposes detailed findings per image. | AuditIfNotExists, Disabled | 1.0.3

### Ensure that Azure Defender is set to On for Key Vault

ID : CIS Azure 2.8 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Azure Defender for Key Vault should be enabled | Azure Defender for Key Vault provides an additional layer of protection and security intelligence by detecting unusual and potentially harmful attempts to access or exploit key vault accounts. | AuditIfNotExists, Disabled | 1.0.3

### Ensure that 'Automatic provisioning of monitoring agent' is set to 'On'

ID : CIS Azure 2.11 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Auto provisioning of the Log Analytics agent should be enabled on your subscription | To monitor for security vulnerabilities and threats, Azure Security Center collects data from your Azure virtual machines. Data is collected by the Log Analytics agent, formerly known as the Microsoft Monitoring Agent (MMA), which reads various security-related configurations and event logs from the machine and copies the data to your Log Analytics workspace for analysis. We recommend enabling auto provisioning to automatically deploy the agent to all supported Azure VMs and any new ones that are created. | AuditIfNotExists, Disabled | 1.0.1

### Ensure 'Additional email addresses' is configured with a security contact email

ID : CIS Azure 2.13 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Subscriptions should have a contact email address for security issues | To ensure the relevant people in your organization are notified when there is a potential security breach in one of your subscriptions, set a security contact to receive email notifications from Security Center. | AuditIfNotExists, Disabled | 1.0.1

### Ensure that 'Notify about alerts with the following severity' is set to 'High'

ID : CIS Azure 2.14 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Email notification for high severity alerts should be enabled | To ensure the relevant people in your organization are notified when there is a potential security breach in one of your subscriptions, enable email notifications for high severity alerts in Security Center. | AuditIfNotExists, Disabled | 1.0.1

## Storage Accounts

### Ensure that 'Secure transfer required' is set to 'Enabled'

ID : CIS Azure 3.1 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Secure transfer to storage accounts should be enabled | Audit requirement of Secure transfer in your storage account. Secure transfer is an option that forces your storage account to accept requests only from secure connections (HTTPS). Use of HTTPS ensures authentication between the server and the service and protects data in transit from network layer attacks such as man-in-the-middle, eavesdropping, and session-hijacking | Audit, Deny, Disabled | 2.0.0

### Ensure that 'Public access level' is set to Private for blob containers

ID : CIS Azure 3.5 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Storage account public access should be disallowed | Anonymous public read access to containers and blobs in Azure Storage is a convenient way to share data but might present security risks. To prevent data breaches caused by undesired anonymous access, Microsoft recommends preventing public access to a storage account unless your scenario requires it. | audit, deny, disabled | 2.0.1-preview

### Ensure default network access rule for Storage Accounts is set to deny

ID : CIS Azure 3.6 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Storage accounts should restrict network access | Network access to storage accounts should be restricted. Configure network rules so only applications from allowed networks can access the storage account. To allow connections from specific internet or on-premises clients, access can be granted to traffic from specific Azure virtual networks or to public internet IP address ranges | Audit, Deny, Disabled | 1.1.1
Storage accounts should restrict network access using virtual network rules | Protect your storage accounts from potential threats using virtual network rules as a preferred method instead of IP-based filtering. Disabling IP-based filtering prevents public IPs from accessing your storage accounts. | Audit, Deny, Disabled | 1.0.1

### Ensure 'Trusted Microsoft Services' is enabled for Storage Account access

ID : CIS Azure 3.7 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Storage accounts should allow access from trusted Microsoft services | Some Microsoft services that interact with storage accounts operate from networks that can't be granted access through network rules. To help this type of service work as intended, allow the set of trusted Microsoft services to bypass the network rules. These services will then use strong authentication to access the storage account. | Audit, Deny, Disabled | 1.0.0

### Ensure storage for critical data are encrypted with Customer Managed Key

ID : CIS Azure 3.9 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Storage accounts should use customer-managed key for encryption | Secure your storage account with greater flexibility using customer-managed keys. When you specify a customer-managed key, that key is used to protect and control access to the key that encrypts your data. Using customer-managed keys provides additional capabilities to control rotation of the key encryption key or cryptographically erase data. | Audit, Disabled | 1.0.2

## Database Services

### Ensure that 'Auditing' is set to 'On'

ID : CIS Azure 4.1.1 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Auditing on SQL server should be enabled | Auditing on your SQL Server should be enabled to track database activities across all databases on the server and save them in an audit log. | AuditIfNotExists, Disabled | 2.0.0

### Ensure that 'Data encryption' is set to 'On' on a SQL Database

ID : CIS Azure 4.1.2 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Transparent Data Encryption on SQL databases should be enabled | Transparent data encryption should be enabled to protect data-at-rest and meet compliance requirements | AuditIfNotExists, Disabled | 1.0.0

### Ensure that 'Auditing' Retention is 'greater than 90 days'

ID : CIS Azure 4.1.3 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
SQL servers should be configured with 90 days auditing retention or higher | SQL servers should be configured with 90 days auditing retention or higher. | AuditIfNotExists, Disabled | 2.0.1

### Ensure that Advanced Threat Protection (ATP) on a SQL server is set to 'Enabled'

ID : CIS Azure 4.2.1 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Advanced data security should be enabled on SQL Managed Instance | Audit each SQL Managed Instance without advanced data security. | AuditIfNotExists, Disabled | 1.0.1
Advanced data security should be enabled on your SQL servers | Audit SQL servers without Advanced Data Security | AuditIfNotExists, Disabled | 2.0.0

### Ensure that Vulnerability Assessment (VA) is enabled on a SQL server by setting a Storage Account

ID : CIS Azure 4.2.2 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Vulnerability assessment should be enabled on SQL Managed Instance | Audit each SQL Managed Instance which doesn't have recurring vulnerability assessment scans enabled. Vulnerability assessment can discover, track, and help you remediate potential database vulnerabilities. | AuditIfNotExists, Disabled | 1.0.1
Vulnerability assessment should be enabled on your SQL servers | Audit Azure SQL servers which do not have recurring vulnerability assessment scans enabled. Vulnerability assessment can discover, track, and help you remediate potential database vulnerabilities. | AuditIfNotExists, Disabled | 2.0.0

### Ensure that VA setting Send scan reports to is configured for a SQL server

ID : CIS Azure 4.2.4 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Vulnerability Assessment settings for SQL server should contain an email address to receive scan reports | Ensure that an email address is provided for the 'Send scan reports to' field in the Vulnerability Assessment settings. This email address receives scan result summary after a periodic scan runs on SQL servers. | AuditIfNotExists, Disabled | 2.0.0

### Ensure 'Enforce SSL connection' is set to 'ENABLED' for PostgreSQL Database Server

ID : CIS Azure 4.3.1 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Enforce SSL connection should be enabled for MySQL database servers | Azure Database for MySQL supports connecting your Azure Database for MySQL server to client applications using Secure Sockets Layer (SSL). Enforcing SSL connections between your database server and your client applications helps protect against 'man in the middle' attacks by encrypting the data stream between the server and your application. This configuration enforces that SSL is always enabled for accessing your database server. | Audit, Disabled | 1.0.1

### Ensure 'Enforce SSL connection' is set to 'ENABLED' for MySQL Database Server

ID : CIS Azure 4.3.2 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Enforce SSL connection should be enabled for PostgreSQL database servers | Azure Database for PostgreSQL supports connecting your Azure Database for PostgreSQL server to client applications using Secure Sockets Layer (SSL). Enforcing SSL connections between your database server and your client applications helps protect against 'man in the middle' attacks by encrypting the data stream between the server and your application. This configuration enforces that SSL is always enabled for accessing your database server. | Audit, Disabled | 1.0.1

### Ensure server parameter 'log_checkpoints' is set to 'ON' for PostgreSQL Database Server

ID : CIS Azure 4.3.3 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Log checkpoints should be enabled for PostgreSQL database servers | This policy helps audit any PostgreSQL databases in your environment without log_checkpoints setting enabled. | AuditIfNotExists, Disabled | 1.0.0

### Ensure server parameter 'log_connections' is set to 'ON' for PostgreSQL Database Server

ID : CIS Azure 4.3.4 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Log connections should be enabled for PostgreSQL database servers | This policy helps audit any PostgreSQL databases in your environment without log_connections setting enabled. | AuditIfNotExists, Disabled | 1.0.0

### Ensure server parameter 'log_disconnections' is set to 'ON' for PostgreSQL Database Server

ID : CIS Azure 4.3.5 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Disconnections should be logged for PostgreSQL database servers. | This policy helps audit any PostgreSQL databases in your environment without log_disconnections enabled. | AuditIfNotExists, Disabled | 1.0.0

### Ensure server parameter 'connection_throttling' is set to 'ON' for PostgreSQL Database Server

ID : CIS Azure 4.3.6 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Connection throttling should be enabled for PostgreSQL database servers | This policy helps audit any PostgreSQL databases in your environment without Connection throttling enabled. This setting enables temporary connection throttling per IP for too many invalid password login failures. | AuditIfNotExists, Disabled | 1.0.0

### Ensure that Azure Active Directory Admin is configured

ID : CIS Azure 4.4 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
An Azure Active Directory administrator should be provisioned for SQL servers | Audit provisioning of an Azure Active Directory administrator for your SQL server to enable Azure AD authentication. Azure AD authentication enables simplified permission management and centralized identity management of database users and other Microsoft services | AuditIfNotExists, Disabled | 1.0.0

### Ensure SQL server's TDE protector is encrypted with Customer-managed key

ID : CIS Azure 4.5 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
SQL managed instances should use customer-managed keys to encrypt data at rest | Implementing Transparent Data Encryption (TDE) with your own key provides you with increased transparency and control over the TDE Protector, increased security with an HSM-backed external service, and promotion of separation of duties. This recommendation applies to organizations with a related compliance requirement. | AuditIfNotExists, Disabled | 1.0.2
SQL servers should use customer-managed keys to encrypt data at rest | Implementing Transparent Data Encryption (TDE) with your own key provides increased transparency and control over the TDE Protector, increased security with an HSM-backed external service, and promotion of separation of duties. This recommendation applies to organizations with a related compliance requirement. | AuditIfNotExists, Disabled | 2.0.1

## Logging and Monitoring

### Ensure the storage container storing the activity logs is not publicly accessible

ID : CIS Azure 5.1.3 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Storage account public access should be disallowed | Anonymous public read access to containers and blobs in Azure Storage is a convenient way to share data but might present security risks. To prevent data breaches caused by undesired anonymous access, Microsoft recommends preventing public access to a storage account unless your scenario requires it. | audit, deny, disabled | 2.0.1-preview

### Ensure the storage account containing the container with activity logs is encrypted with BYOK (Use Your Own Key)

ID : CIS Azure 5.1.4 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Storage account containing the container with activity logs must be encrypted with BYOK | This policy audits if the Storage account containing the container with activity logs is encrypted with BYOK. The policy works only if the storage account lies on the same subscription as activity logs by design. More information on Azure Storage encryption at rest can be found here https://aka.ms/azurestoragebyok . | AuditIfNotExists, Disabled | 1.0.0

### Ensure that logging for Azure KeyVault is 'Enabled'

ID : CIS Azure 5.1.5 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Resource logs in Key Vault should be enabled | Audit enabling of resource logs. This enables you to recreate activity trails to use for investigation purposes when a security incident occurs or when your network is compromised | AuditIfNotExists, Disabled | 4.0.1

### Ensure that Activity Log Alert exists for Create Policy Assignment

ID : CIS Azure 5.2.1 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
An activity log alert should exist for specific Policy operations | This policy audits specific Policy operations with no activity log alerts configured. | AuditIfNotExists, Disabled | 3.0.0

### Ensure that Activity Log Alert exists for Delete Policy Assignment

ID : CIS Azure 5.2.2 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
An activity log alert should exist for specific Policy operations | This policy audits specific Policy operations with no activity log alerts configured. | AuditIfNotExists, Disabled | 3.0.0

### Ensure that Activity Log Alert exists for Create or Update Network Security Group

ID : CIS Azure 5.2.3 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
An activity log alert should exist for specific Administrative operations | This policy audits specific Administrative operations with no activity log alerts configured. | AuditIfNotExists, Disabled | 1.0.0

### Ensure that Activity Log Alert exists for Delete Network Security Group

ID : CIS Azure 5.2.4 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
An activity log alert should exist for specific Administrative operations | This policy audits specific Administrative operations with no activity log alerts configured. | AuditIfNotExists, Disabled | 1.0.0

### Ensure that Activity Log Alert exists for Create or Update Network Security Group Rule

ID : CIS Azure 5.2.5 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
An activity log alert should exist for specific Administrative operations | This policy audits specific Administrative operations with no activity log alerts configured. | AuditIfNotExists, Disabled | 1.0.0

### Ensure that activity log alert exists for the Delete Network Security Group Rule

ID : CIS Azure 5.2.6 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
An activity log alert should exist for specific Administrative operations | This policy audits specific Administrative operations with no activity log alerts configured. | AuditIfNotExists, Disabled | 1.0.0

### Ensure that Activity Log Alert exists for Create or Update Security Solution

ID : CIS Azure 5.2.7 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
An activity log alert should exist for specific Security operations | This policy audits specific Security operations with no activity log alerts configured. | AuditIfNotExists, Disabled | 1.0.0

### Ensure that Activity Log Alert exists for Delete Security Solution

ID : CIS Azure 5.2.8 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
An activity log alert should exist for specific Security operations | This policy audits specific Security operations with no activity log alerts configured. | AuditIfNotExists, Disabled | 1.0.0

### Ensure that Activity Log Alert exists for Create or Update or Delete SQL Server Firewall Rule

ID : CIS Azure 5.2.9 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
An activity log alert should exist for specific Administrative operations | This policy audits specific Administrative operations with no activity log alerts configured. | AuditIfNotExists, Disabled | 1.0.0

### Ensure that Diagnostic Logs are enabled for all services which support it.

ID : CIS Azure 5.3 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Diagnostic logs in App Services should be enabled | Audit enabling of diagnostic logs on the app. This enables you to recreate activity trails for investigation purposes if a security incident occurs or your network is compromised | AuditIfNotExists, Disabled | 2.0.0
Resource logs in Azure Data Lake Store should be enabled | Audit enabling of resource logs. This enables you to recreate activity trails to use for investigation purposes; when a security incident occurs or when your network is compromised | AuditIfNotExists, Disabled | 4.0.1
Resource logs in Azure Stream Analytics should be enabled | Audit enabling of resource logs. This enables you to recreate activity trails to use for investigation purposes; when a security incident occurs or when your network is compromised | AuditIfNotExists, Disabled | 4.0.1
Resource logs in Batch accounts should be enabled | Audit enabling of resource logs. This enables you to recreate activity trails to use for investigation purposes; when a security incident occurs or when your network is compromised | AuditIfNotExists, Disabled | 4.0.1
Resource logs in Data Lake Analytics should be enabled | Audit enabling of resource logs. This enables you to recreate activity trails to use for investigation purposes; when a security incident occurs or when your network is compromised | AuditIfNotExists, Disabled | 4.0.1
Resource logs in Event Hub should be enabled | Audit enabling of resource logs. This enables you to recreate activity trails to use for investigation purposes; when a security incident occurs or when your network is compromised | AuditIfNotExists, Disabled | 4.0.1
Resource logs in IoT Hub should be enabled | Audit enabling of resource logs. This enables you to recreate activity trails to use for investigation purposes; when a security incident occurs or when your network is compromised | AuditIfNotExists, Disabled | 3.0.1
Resource logs in Key Vault should be enabled | Audit enabling of resource logs. This enables you to recreate activity trails to use for investigation purposes when a security incident occurs or when your network is compromised | AuditIfNotExists, Disabled | 4.0.1
Resource logs in Logic Apps should be enabled | Audit enabling of resource logs. This enables you to recreate activity trails to use for investigation purposes; when a security incident occurs or when your network is compromised | AuditIfNotExists, Disabled | 4.0.1
Resource logs in Search services should be enabled | Audit enabling of resource logs. This enables you to recreate activity trails to use for investigation purposes; when a security incident occurs or when your network is compromised | AuditIfNotExists, Disabled | 4.0.1
Resource logs in Service Bus should be enabled | Audit enabling of resource logs. This enables you to recreate activity trails to use for investigation purposes; when a security incident occurs or when your network is compromised | AuditIfNotExists, Disabled | 4.0.1
Resource logs in Virtual Machine Scale Sets should be enabled | It is recommended to enable Logs so that activity trail can be recreated when investigations are required in the event of an incident or a compromise. | AuditIfNotExists, Disabled | 2.0.1

## Networking

### Ensure that RDP access is restricted from the internet

ID : CIS Azure 6.1 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
RDP access from the Internet should be blocked | This policy audits any network security rule that allows RDP access from Internet | Audit, Disabled | 2.0.0

### Ensure that SSH access is restricted from the internet

ID : CIS Azure 6.2 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
SSH access from the Internet should be blocked | This policy audits any network security rule that allows SSH access from Internet | Audit, Disabled | 2.0.0

### Ensure that Network Watcher is 'Enabled'

ID : CIS Azure 6.5 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Network Watcher should be enabled | Network Watcher is a regional service that enables you to monitor and diagnose conditions at a network scenario level in, to, and from Azure. Scenario level monitoring enables you to diagnose problems at an end to end network level view. Network diagnostic and visualization tools available with Network Watcher help you understand, diagnose, and gain insights to your network in Azure. | auditIfNotExists | 1.1.0

## Virtual Machines

### Ensure Virtual Machines are utilizing Managed Disks

ID : CIS Azure 7.1 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Audit VMs that do not use managed disks | This policy audits VMs that do not use managed disks | audit | 1.0.0

### Ensure that 'OS and Data' disks are encrypted with CMK

ID : CIS Azure 7.2 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Disk encryption should be applied on virtual machines | Virtual machines without an enabled disk encryption will be monitored by Azure Security Center as recommendations. | AuditIfNotExists, Disabled | 2.0.0

### Ensure that 'Unattached disks' are encrypted with CMK

ID : CIS Azure 7.3 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Unattached disks should be encrypted | This policy audits any unattached disk without encryption enabled. | Audit, Disabled | 1.0.0

### Ensure that only approved extensions are installed

ID : CIS Azure 7.4 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Only approved VM extensions should be installed | This policy governs the virtual machine extensions that are not approved. | Audit, Deny, Disabled | 1.0.0

### Ensure that the latest OS Patches for all Virtual Machines are applied

ID : CIS Azure 7.5 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
System updates should be installed on your machines | Missing security system updates on your servers will be monitored by Azure Security Center as recommendations | AuditIfNotExists, Disabled | 3.0.0

### Ensure that the endpoint protection for all Virtual Machines is installed

ID : CIS Azure 7.6 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Monitor missing Endpoint Protection in Azure Security Center | Servers without an installed Endpoint Protection agent will be monitored by Azure Security Center as recommendations | AuditIfNotExists, Disabled | 3.0.0

## Other Security Considerations

### Ensure that the expiration date is set on all keys

ID : CIS Azure 8.1 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Key Vault keys should have an expiration date | Cryptographic keys should have a defined expiration date and not be permanent. Keys that are valid forever provide a potential attacker with more time to compromise the key. It is a recommended security practice to set expiration dates on cryptographic keys. | Audit, Deny, Disabled | 1.0.1-preview

### Ensure that the expiration date is set on all Secrets

ID : CIS Azure 8.2 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Key Vault secrets should have an expiration date | Secrets should have a defined expiration date and not be permanent. Secrets that are valid forever provide a potential attacker with more time to compromise them. It is a recommended security practice to set expiration dates on secrets. | Audit, Deny, Disabled | 1.0.1-preview

### Ensure the key vault is recoverable

ID : CIS Azure 8.4 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Key vaults should have purge protection enabled | Malicious deletion of a key vault can lead to permanent data loss. A malicious insider in your organization can potentially delete and purge key vaults. Purge protection protects you from insider attacks by enforcing a mandatory retention period for soft deleted key vaults. No one inside your organization or Microsoft will be able to purge your key vaults during the soft delete retention period. | Audit, Deny, Disabled | 1.1.1

### Enable role-based access control (RBAC) within Azure Kubernetes Services

ID : CIS Azure 8.5 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Role-Based Access Control (RBAC) should be used on Kubernetes Services | To provide granular filtering on the actions that users can perform, use Role-Based Access Control (RBAC) to manage permissions in Kubernetes Service Clusters and configure relevant authorization policies. | Audit, Disabled | 1.0.2

## App Service

### Ensure App Service Authentication is set on Azure App Service

ID : CIS Azure 9.1 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Authentication should be enabled on your API app | Azure App Service Authentication is a feature that can prevent anonymous HTTP requests from reaching the API app, or authenticate those that have tokens before they reach the API app | AuditIfNotExists, Disabled | 1.0.0
Authentication should be enabled on your Function app | Azure App Service Authentication is a feature that can prevent anonymous HTTP requests from reaching the Function app, or authenticate those that have tokens before they reach the Function app | AuditIfNotExists, Disabled | 1.0.0
Authentication should be enabled on your web app | Azure App Service Authentication is a feature that can prevent anonymous HTTP requests from reaching the web app, or authenticate those that have tokens before they reach the web app | AuditIfNotExists, Disabled | 1.0.0

### Ensure web app redirects all HTTP traffic to HTTPS in Azure App Service

ID : CIS Azure 9.2 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Web Application should only be accessible over HTTPS | Use of HTTPS ensures server/service authentication and protects data in transit from network layer eavesdropping attacks. | Audit, Disabled | 1.0.0

### Ensure web app is using the latest version of TLS encryption

ID : CIS Azure 9.3 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Latest TLS version should be used in your API App | Upgrade to the latest TLS version | AuditIfNotExists, Disabled | 1.0.0
Latest TLS version should be used in your Function App | Upgrade to the latest TLS version | AuditIfNotExists, Disabled | 1.0.0
Latest TLS version should be used in your Web App | Upgrade to the latest TLS version | AuditIfNotExists, Disabled | 1.0.0

### Ensure the web app has 'Client Certificates (Incoming client certificates)' set to 'On'

ID : CIS Azure 9.4 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Ensure API app has 'Client Certificates (Incoming client certificates)' set to 'On' | Client certificates allow for the app to request a certificate for incoming requests. Only clients that have a valid certificate will be able to reach the app. | Audit, Disabled | 1.0.0
Ensure WEB app has 'Client Certificates (Incoming client certificates)' set to 'On' | Client certificates allow for the app to request a certificate for incoming requests. Only clients that have a valid certificate will be able to reach the app. | Audit, Disabled | 1.0.0
Function apps should have 'Client Certificates (Incoming client certificates)' enabled | Client certificates allow for the app to request a certificate for incoming requests. Only clients with valid certificates will be able to reach the app. | Audit, Disabled | 1.0.1

### Ensure that Register with Azure Active Directory is enabled on App Service

ID : CIS Azure 9.5 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Managed identity should be used in your API App | Use a managed identity for enhanced authentication security | AuditIfNotExists, Disabled | 2.0.0
Managed identity should be used in your Function App | Use a managed identity for enhanced authentication security | AuditIfNotExists, Disabled | 2.0.0
Managed identity should be used in your Web App | Use a managed identity for enhanced authentication security | AuditIfNotExists, Disabled | 2.0.0

### Ensure that 'PHP version' is the latest, if used to run the web app

ID : CIS Azure 9.6 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Ensure that 'PHP version' is the latest, if used as a part of the API app | Periodically, newer versions are released for PHP software either due to security flaws or to include additional functionality. Using the latest PHP version for API apps is recommended in order to take advantage of security fixes, if any, and/or new functionalities of the latest version. Currently, this policy only applies to Linux web apps. | AuditIfNotExists, Disabled | 2.0.0
Ensure that 'PHP version' is the latest, if used as a part of the WEB app | Periodically, newer versions are released for PHP software either due to security flaws or to include additional functionality. Using the latest PHP version for web apps is recommended in order to take advantage of security fixes, if any, and/or new functionalities of the latest version. Currently, this policy only applies to Linux web apps. | AuditIfNotExists, Disabled | 2.0.0

### Ensure that 'Python version' is the latest, if used to run the web app

ID : CIS Azure 9.7 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Ensure that 'Python version' is the latest, if used as a part of the API app | Periodically, newer versions are released for Python software either due to security flaws or to include additional functionality. Using the latest Python version for API apps is recommended in order to take advantage of security fixes, if any, and/or new functionalities of the latest version. Currently, this policy only applies to Linux web apps. | AuditIfNotExists, Disabled | 2.0.0
Ensure that 'Python version' is the latest, if used as a part of the Function app | Periodically, newer versions are released for Python software either due to security flaws or to include additional functionality. Using the latest Python version for Function apps is recommended in order to take advantage of security fixes, if any, and/or new functionalities of the latest version. Currently, this policy only applies to Linux web apps. | AuditIfNotExists, Disabled | 2.0.0
Ensure that 'Python version' is the latest, if used as a part of the Web app | Periodically, newer versions are released for Python software either due to security flaws or to include additional functionality. Using the latest Python version for web apps is recommended in order to take advantage of security fixes, if any, and/or new functionalities of the latest version. Currently, this policy only applies to Linux web apps. | AuditIfNotExists, Disabled | 2.0.0

### Ensure that 'Java version' is the latest, if used to run the web app

ID : CIS Azure 9.8 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Ensure that 'Java version' is the latest, if used as a part of the API app | Periodically, newer versions are released for Java either due to security flaws or to include additional functionality. Using the latest Python version for API apps is recommended in order to take advantage of security fixes, if any, and/or new functionalities of the latest version. Currently, this policy only applies to Linux web apps. | AuditIfNotExists, Disabled | 2.0.0
Ensure that 'Java version' is the latest, if used as a part of the Function app | Periodically, newer versions are released for Java software either due to security flaws or to include additional functionality. Using the latest Java version for Function apps is recommended in order to take advantage of security fixes, if any, and/or new functionalities of the latest version. Currently, this policy only applies to Linux web apps. | AuditIfNotExists, Disabled | 2.0.0
Ensure that 'Java version' is the latest, if used as a part of the Web app | Periodically, newer versions are released for Java software either due to security flaws or to include additional functionality. Using the latest Java version for web apps is recommended in order to take advantage of security fixes, if any, and/or new functionalities of the latest version. Currently, this policy only applies to Linux web apps. | AuditIfNotExists, Disabled | 2.0.0

### Ensure that 'HTTP Version' is the latest, if used to run the web app

ID : CIS Azure 9.9 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
Ensure that 'HTTP Version' is the latest, if used to run the API app | Periodically, newer versions are released for HTTP either due to security flaws or to include additional functionality. Using the latest HTTP version for web apps to take advantage of security fixes, if any, and/or new functionalities of the newer version. Currently, this policy only applies to Linux web apps. | AuditIfNotExists, Disabled | 2.0.0
Ensure that 'HTTP Version' is the latest, if used to run the Function app | Periodically, newer versions are released for HTTP either due to security flaws or to include additional functionality. Using the latest HTTP version for web apps to take advantage of security fixes, if any, and/or new functionalities of the newer version. Currently, this policy only applies to Linux web apps. | AuditIfNotExists, Disabled | 2.0.0
Ensure that 'HTTP Version' is the latest, if used to run the Web app | Periodically, newer versions are released for HTTP either due to security flaws or to include additional functionality. Using the latest HTTP version for web apps to take advantage of security fixes, if any, and/or new functionalities of the newer version. Currently, this policy only applies to Linux web apps. | AuditIfNotExists, Disabled | 2.0.0

### Ensure FTP deployments are disabled

ID : CIS Azure 9.10 Ownership : Customer

Name (Azure portal) | Description | Effect(s) | Version (GitHub)
--- | --- | --- | ---
FTPS only should be required in your API App | Enable FTPS enforcement for enhanced security | AuditIfNotExists, Disabled | 2.0.0
FTPS only should be required in your Function App | Enable FTPS enforcement for enhanced security | AuditIfNotExists, Disabled | 2.0.0
FTPS should be required in your Web App | Enable FTPS enforcement for enhanced security | AuditIfNotExists, Disabled | 2.0.0

Note

Availability of specific Azure Policy definitions may vary in Azure Government and other national clouds.

## Next steps

Additional articles about Azure Policy:

- Regulatory Compliance overview.
- See the initiative definition structure .
- Review other examples at Azure Policy samples .
- Review Understanding policy effects .
- Learn how to remediate non-compliant resources .

### Is this page helpful?

Any additional feedback?

Thank you.

## Feedback

Submit and view feedback for

This product This page
View all page feedback

### Is this page helpful?

Any additional feedback?

Thank you.